@@ -12,7 +12,7 @@ import urllib.parse as path_encoder
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
 #API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
-API_GW = "https://getxmgyi9k.execute-api.cn-north-1.amazonaws.com.cn/api/"
+API_GW = "https://ck78dwtl1j.execute-api.cn-north-1.amazonaws.com.cn/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -44,22 +44,25 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
     if local_data is not None:
-        __upload_one_folder(job_id, FileType.Traindata.name, local_data)
-        print(f"uploaded {local_data}")
-    else:
-        print(f"local_data already exists")
+        #*****haiyan*****
+        if local_data.startswith('s3://'):
+            print(f"******local_data{local_data}******")
+            with open("./s3_public_dataset.txt", 'wb') as s3_public:
+                s3_public.write(local_data)
+            __upload_one_file(job_id, FileType.Traindata.name, s3_public)
+            print(f"use s3 public dataset{local_data}")
+        else:
+        #*****haiyan*****
+            __upload_one_folder(job_id, FileType.Traindata.name, local_data)
+            print(f"uploaded {local_data}")
 
     if source_code is not None:
         __upload_one_file(job_id, FileType.Code.name, source_code)
         print(f"uploaded {source_code}")
-    else:
-        print(f"source_code already exists")
 
     if weights is not None:
         __upload_one_file(job_id, FileType.Weights.name, weights)
         print(f"uploaded {weights}")
-    else:
-        print(f"weights already exists")
 
     # put hyper param to Dynamodb through API Gateway
     headers = {
@@ -186,7 +189,7 @@ if __name__ == "__main__":
     #__list_files("test")
     #getFloderFiles("test")
     #print(files)
-    make_tar("yolov5")
+    #make_tar("yolov5")
     create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
     #make_tar("train.py")
     #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
